summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Command/User
diff options
context:
space:
mode:
authorfukachan <fukachan>2002-04-06 14:46:27 +0000
committerfukachan <fukachan>2002-04-06 14:46:27 +0000
commitd653866713521acdff8685660e8afb38b96302ab (patch)
tree2251de2033eaef2973d54345172f398200e6efc3 /fml/lib/FML/Command/User
parentbb4a8371c705d63276e4e04bdd87e959e4618335 (diff)
downloadfml8-d653866713521acdff8685660e8afb38b96302ab.tar.gz
fml8-d653866713521acdff8685660e8afb38b96302ab.tar.bz2
fml8-d653866713521acdff8685660e8afb38b96302ab.zip
clean up, more log
Diffstat (limited to 'fml/lib/FML/Command/User')
-rw-r--r--fml/lib/FML/Command/User/chaddr.pm10
-rw-r--r--fml/lib/FML/Command/User/confirm.pm15
-rw-r--r--fml/lib/FML/Command/User/send.pm8
-rw-r--r--fml/lib/FML/Command/User/summary.pm4
4 files changed, 18 insertions, 19 deletions
diff --git a/fml/lib/FML/Command/User/chaddr.pm b/fml/lib/FML/Command/User/chaddr.pm
index 54919d3f..885afc5a 100644
--- a/fml/lib/FML/Command/User/chaddr.pm
+++ b/fml/lib/FML/Command/User/chaddr.pm
@@ -4,20 +4,16 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: chaddr.pm,v 1.9 2002/03/17 05:27:32 fukachan Exp $
+# $FML: chaddr.pm,v 1.10 2002/03/17 06:24:30 fukachan Exp $
#
package FML::Command::User::chaddr;
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
use Carp;
-
-
-
use FML::Log qw(Log LogWarn LogError);
-
=head1 NAME
FML::Command::User::chaddr - change subscriber address
@@ -35,7 +31,7 @@ After confirmation succeeds, chaddr process proceeds.
=head2 C<process($curproc, $command_args)>
-if the old address in chaddr arguments is a member,
+if either old or new addresses in chaddr arguments is an ML member,
try to confirm this request irrespective of "From:" address.
=cut
@@ -78,7 +74,7 @@ sub process
my $command = $command_args->{ command };
my $sender = $curproc->{ credential }->sender();
- # fundamental check
+ # cheap sanity checks
croak("\$member_map is not specified") unless $member_map;
croak("\$recipient_map is not specified") unless $recipient_map;
diff --git a/fml/lib/FML/Command/User/send.pm b/fml/lib/FML/Command/User/send.pm
index a1f134ad..cec3af33 100644
--- a/fml/lib/FML/Command/User/send.pm
+++ b/fml/lib/FML/Command/User/send.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: send.pm,v 1.6 2002/02/18 14:14:53 fukachan Exp $
+# $FML: send.pm,v 1.7 2002/02/20 14:10:38 fukachan Exp $
#
package FML::Command::User::send;
@@ -16,7 +16,7 @@ use FML::Command::User::get;
@ISA = qw(FML::Command::User::get);
-# Descriptions: send articles, files, et.al...
+# Descriptions: send articles
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to get module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::User::send - what is this
+FML::Command::User::send - send artciles
=head1 SYNOPSIS
@@ -37,7 +37,7 @@ forwarded C<FML::Command::User::get>.
=head1 DESCRIPTION
-forwarded C<FML::Command::User::get>.
+an alias of C<FML::Command::User::get>.
=head1 AUTHOR
diff --git a/fml/lib/FML/Command/User/summary.pm b/fml/lib/FML/Command/User/summary.pm
index 9a4f9c3f..074806c2 100644
--- a/fml/lib/FML/Command/User/summary.pm
+++ b/fml/lib/FML/Command/User/summary.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: summary.pm,v 1.5 2002/02/13 10:41:18 fukachan Exp $
+# $FML: summary.pm,v 1.6 2002/02/18 14:14:53 fukachan Exp $
#
package FML::Command::User::summary;
@@ -12,8 +12,6 @@ use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
use Carp;
-
-
use FML::Command::SendFile;
use FML::Log qw(Log LogWarn LogError);
@ISA = qw(FML::Command::SendFile);
diff --git a/fml/lib/FML/Command/User/confirm.pm b/fml/lib/FML/Command/User/confirm.pm
index 21dd8b6f..a61980c1 100644
--- a/fml/lib/FML/Command/User/confirm.pm
+++ b/fml/lib/FML/Command/User/confirm.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: confirm.pm,v 1.7 2002/02/17 13:29:59 fukachan Exp $
+# $FML: confirm.pm,v 1.8 2002/03/17 05:27:32 fukachan Exp $
#
package FML::Command::User::confirm;
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-real process after confirmation succeeds.
+execute the actual corresponding process if the confirmation succeeds.
=head1 METHODS
@@ -52,7 +52,7 @@ sub new
sub need_lock { 1;}
# Descriptions: real process after confirmation succeeds.
# run _switch_command() for real process.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: none
@@ -72,6 +72,8 @@ sub process
# get class and id from buffer, for example,
# "confirm subscribe 813f42fa2aa84bbba500ed3d2781dea6"
+ # XXX $keyword not starts at the begining of this line.
+ # XXX for example, "confirm", "> confirm" and "xxx> confirm ..."
if ($command =~ /$keyword\s+(\w+)\s+([\w\d]+)/) {
($class, $id) = ($1, $2);
}
@@ -91,17 +93,19 @@ sub process
$self->_switch_command($class, $address, $curproc, $command_args);
}
else { # if req is expired
+ LogError("request expired");
croak("request is expired");
}
}
else {
+ LogError("no such confirmation request id=$id");
croak("no such confirmation request id=$id");
}
}
# Descriptions: load module for real process and
# switched to it.
# We support only {subscribe,unsubscribe,chaddr} now.
# Arguments: OBJ($self) STR($class) STR($address)
# OBJ($curproc) HASH_REF($command_args)
@@ -126,6 +130,7 @@ sub _switch_command
$obj->$class($curproc, $command_args);
}
else {
+ LogError("no such rule confirm -> class");
croak("no such rule");
}
}
@@ -52,7 +52,7 @@ sub new
sub need_lock { 1;}
-# Descriptions: real process after confirmation succeeds.
+# Descriptions: execute the actual process if this confirmation succeeds.
# run _switch_command() for real process.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
@@ -91,17 +93,19 @@ sub process
}
}
-# Descriptions: load module for real process and
-# switched to it.
+# Descriptions: load module for the actual process and
+# switch this process to it.
# We support only {subscribe,unsubscribe,chaddr} now.
# Arguments: OBJ($self) STR($class) STR($address)